/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useContext, useState } from 'react'
import styled from 'styled-components'
import { Store } from '../../../Store.js';
import { Link } from 'react-router-dom'
import Button from '@material-ui/core/Button';
import IconButton from '@material-ui/core/IconButton';
import PhotoCamera from '@material-ui/icons/PhotoCamera';
import Tooltip from '@material-ui/core/Tooltip';
import FormInput from "../../FormInput.js"
import ValidateUserInput from '../../HelperFunctions/FormValidationFunction.js'
import { apiDomain } from '../../../env.js'
import ModalAlterarCover from '../../ModalAlterarCover/ModalAlterarCover.js'
import ModalAlterarAvatar from '../../ModalAlterarAvatar/ModalAlterarAvatar.js'
import Profile from '../../../img/default_profile0.png'

export default function TabPanelEditarPerfil(props) {
    // eslint-disable-next-line
    const { state } = useContext(Store)
    const [hoverAlterarFoto, handleAlterarFoto] = React.useState(false)

    const [formNome, setNome] = useState({
        key: state.currentUser.name ? false : true,
        value: state.currentUser.name ? state.currentUser.name : ""
    })

    const [formAboutMe, setAboutMe] = useState({
        key: false,
        value: state.currentUser.description ? state.currentUser.description : ""
    })

    const handleHoverAlterarFoto = () => {
        handleAlterarFoto(!hoverAlterarFoto)
    }

    const [tempCover, setTempCover] = useState('')

    const [open, toggleOpen] = useState(false)
    const controlModal = () => { toggleOpen(!open) }

    const updateCover = (selectorFiles) => {
        const objectURL = URL.createObjectURL(selectorFiles[0])
        setTempCover(objectURL)
        controlModal()
    }

    const handleChange = (e, type) => {
        const userInput = e.target.value
        const flag = ValidateUserInput(type, userInput)

        if (type === 'username') {
            setNome({
                ...formNome,
                key: flag,
                value: userInput
            })

        }
        else if (type === 'aboutMe') {
            setAboutMe({
                ...formAboutMe,
                key: flag,
                value: userInput,
            })

        }
    }

    const limpaCamposForm = () => {
        setNome({
            ...formNome,
            key: state.currentUser.name ? false : true,
            value: state.currentUser.name ? state.currentUser.name : ""
        })

        setAboutMe({
            ...formAboutMe,
            key: state.currentUser.description ? false : true,
            value: state.currentUser.description ? state.currentUser.description : ""
        })
    }

    const [alterarAvatatarOpen, toggleAlterarAvatar] = useState(false)
    const controlModalAvatar = () => { toggleAlterarAvatar(!alterarAvatatarOpen) }

    const handleSubmit = (e) => {
        e.preventDefault()
        const info = { user: { name: formNome.value, description: formAboutMe.value, email: state.currentUser.email } }
        const flagNome = formNome.key
        const flagAboutMe = formAboutMe.key

        if (!(flagNome || flagAboutMe)) {
            props.updateUserInfo(info)
            limpaCamposForm()
        }
    }

    return (
        <React.Fragment>
            <ModalAlterarCover
                contrast={state.contrast}
                open={open}
                handleClose={controlModal}
                cover={tempCover}
                id={state.currentUser.id}
            />
            <ModalAlterarAvatar
                contrast={state.contrast}
                open={alterarAvatatarOpen}
                handleClose={controlModalAvatar}
                userAvatar={state.currentUser.avatar}
                id={state.currentUser.id}
            />
            <div className="card-config">
                <h1 className="title">Editar Perfil </h1>
                <div className='content-div'>
                    <div style={{ padding: "0", display: "flex", flexDirection: "column" }}>
                        <HeaderContainer contrast={state.contrast}>
                            <div style={{ position: "relative", height: "100%" }}>
                                <img src={state.currentUser.cover ? `${apiDomain}` + state.currentUser.cover : null} alt={state.currentUser.cover ? "user cover avatar" : ""} style={{ width: "100%", height: "100%", objectFit: "cover" }} />
                                <input accept="image/*" style={{ display: "none" }} id="icon-button-file" type="file" onChange={(e) => updateCover(e.target.files)} />
                                <label htmlFor="icon-button-file">
                                    <Tooltip title={<span style={{ fontSize: "14px", overflow: "hidden", transition: "all .5s ease" }}>ALTERAR CAPA</span>} placement="left">
                                        <IconButton style={{ position: "absolute", right: "0", top: "0", color: "#fff" }} color="primary" aria-label="upload picture" component="span">
                                            <PhotoCamera />
                                        </IconButton>
                                    </Tooltip>
                                </label>
                            </div>
                            <ProfileAvatarDiv onMouseEnter={handleHoverAlterarFoto} onMouseLeave={handleHoverAlterarFoto}>
                                <img src={state.currentUser.avatar ? `${apiDomain}` + state.currentUser.avatar : Profile} alt="user avatar" />
                                <ChangeAvatarDiv style={{ display: hoverAlterarFoto ? 'flex' : 'none' }}>
                                    <span onClick={() => { controlModalAvatar() }}>Alterar Foto</span>
                                </ChangeAvatarDiv>
                            </ProfileAvatarDiv>
                        </HeaderContainer>
                        <br />
                    </div>

                    <div style={{ paddingTop: "90px" }}>
                        <div style={{ display: "flex", flexDirection: "row", justifyContent: "center" }}>
                            <form onSubmit={e => handleSubmit(e)}>
                                <FormInput
                                    contrast={state.contrast}
                                    inputType={"text"}
                                    name={"Nome Completo"}
                                    value={formNome.value}
                                    placeholder={"Nome Completo"}
                                    handleChange={e => handleChange(e, 'username')}
                                    required={true}
                                    error={formNome.key}
                                />
                                <FormInput
                                    contrast={state.contrast}
                                    inputType={"text"}
                                    name={"Sobre Mim"}
                                    value={formAboutMe.value}
                                    multi={true}
                                    rows="3"
                                    rowsMax="3"
                                    error={formAboutMe.key}
                                    placeholder={"Sobre mim (visível no seu perfil público)"}
                                    handleChange={e => handleChange(e, 'aboutMe')}
                                    required={false}
                                    help={formAboutMe.value.length + '/160'}
                                />
                            </form>
                        </div>
                        <ButtonsDiv>
                            <Link to="perfil" ><ButtonCancelar contrast={state.contrast} >CANCELAR</ButtonCancelar></Link>
                            <ButtonConfirmar contrast={state.contrast} onClick={e => handleSubmit(e)}>SALVAR ALTERAÇÕES</ButtonConfirmar>
                        </ButtonsDiv>
                    </div>
                </div >
            </div>
        </React.Fragment>
    )
}

const ButtonConfirmar = styled(Button)`
    background-color: ${props => props.contrast === "" ? "#00bcd4 !important" : "black !important"};
    color : #fff !important;
    font-family : 'Roboto',sans-serif !important;
    font-size : 14px !important;
    font-weight : 500 !important;
    padding-left : 16px !important;
    padding-right : 16px !important;
    outline : none !important;
    margin : 6px 8px !important;
    white-space : nowrap !important;
    text-transform : uppercase !important;
    font-weight : bold !important;
    font-size : 14px !important;
    font-style : inherit !important;
    font-variant : inherit !important;
    font-family : inherit !important;
    text-decoration: ${props => props.contrast === "" ? "none" : "underline !important"};
    overflow : hidden !important;
    display : inline-block !important;
    position : relative !important;
    cursor : pointer !important;
    min-height : 36px !important;
    min-width : 88px !important;
    line-height : 36px !important;
    vertical-align : middle !important;
    align-items : center !important;
    text-align : center !important;
    border-radius : 3px !important;
    box-sizing : border-box !important;
    color: ${props => props.contrast === "" ? "white !important" : "yellow !important"};
    border: ${props => props.contrast === "" ? "0 !important" : "1px solid white !important"};
    :hover{
        background-color: ${props => props.contrast === "" ? "" : "rgba(255,255,0,0.24) !important"};
    }
`

export const ButtonCancelar = styled(Button)`
    height : 36px !important;
    padding-left : 16px !important;
    padding-right : 16px !important;
    font-weight : bold !important;
    border-radius : 3px !important;
    outline : none !important;
    text-transform : uppercase !important;
    font-weight : 500 !important;
    font-size : 14px !important;
    font-style : inherit !important;
    font-variant : inherit !important;
    font-family : inherit !important;
    text-decoration: ${props => props.contrast === "" ? "none" : "underline !important"};
    overflow : hidden !important;
    display : inline-block !important;
    position : relative !important;
    cursor : pointer !important;
    min-height : 36px !important;
    min-width : 88px !important;
    line-height : 36px !important;
    vertical-align : middle !important;
    align-items : center !important;
    text-align : center !important;
    border-radius : 3px !important;
    box-sizing : border-box !important;
    user-select : none !important;
    color: ${props => props.contrast === "" ? "black !important" : "yellow !important"};
    border: ${props => props.contrast === "" ? "0 !important" : "1px solid white !important"};
    padding : 0 6px !important;
    margin : 6px 8px !important;
    :hover{
        background-color: ${props => props.contrast === "" ? "#f1f1f1 !important" : "rgba(255,255,0,0.24) !important"};
    }

`

const ButtonsDiv = styled.div`
    text-align : right;
    margin-top : 80px;
    text-decoration: underline;
`

const ChangeAvatarDiv = styled.div`
    height : 40px;
    position: absolute;
    width : 100%;
    bottom : 0;
    display : flex;
    background-color : #000;
    color : #fff;
    justify-content : center;
`

const ProfileAvatarDiv = styled.div`
    top: 70px;
    left: 0;
    right: 0;
    bottom: -40px;
    margin: auto; 
    border-radius : 100%;
    position : absolute;
    max-width : 100px;
    max-height : 100px;
    overflow : hidden;
    border : 8px solid #fff;
    outline : 0;
    cursor : pointer;
    z-index : 10;
    background-color : #fff !important;

    @media screen and (max-width: 769px) {
        max-width : 75px;
        max-height : 75px;
        position:absolute;
        left:0;
        right:0;
        bottom : -40px;
        margin-left:auto;
        margin-right:auto;
    }
    img {
        border:0;
        vertical-align:middle;
        width : 100%;
        height : 100%;
    }
`

const HeaderContainer = styled.div`
    background: ${props => props.contrast === "" ? "#afeeee" : "black"};
    border: ${props => props.contrast === "" ? "1px solid #afeeee" : "1px solid white"};
    position : relative;
    height : 150px;
    border-radius : 8px;
`
